Nim’s Django Helpers
====================

|Build Status| |Coverage Status|

Requirements
------------

-  Python 3.6
-  Django 2.0
-  `django-autoslug <https://github.com/nim65s/django-autoslug>`__
   (waiting for https://github.com/neithere/django-autoslug/issues/31)
-  `django-bootstrap3 <https://github.com/dyve/django-bootstrap3>`__
   (will be django-bootstrap4 soon)

.. |Build Status| image:: https://travis-ci.org/nim65s/ndh.svg?branch=master
   :target: https://travis-ci.org/nim65s/ndh
.. |Coverage Status| image:: https://coveralls.io/repos/github/nim65s/ndh/badge.svg?branch=master
   :target: https://coveralls.io/github/nim65s/ndh?branch=master
